@@ -19,6 +19,8 @@ from onnx2tf.utils.common_functions import (
     shape_unmatched_special_avoidance_workaround,
     make_tf_partial_model_inputs,
     dummy_tf_inference,
+    merge_two_consecutive_identical_ops_into_one,
+    deterring_shape_corruption_due_to_broadcast,
 )
 from typing import Any, Dict, List
 from onnx2tf.utils.enums import TF_DTYPES_TO_NUMPY_DTYPES
@@ -60,13 +62,13 @@ def make_node(
         before_op_output_shape_trans,
     )
     graph_node_output: gs.Variable = graph_node.outputs[0]
-    shape = graph_node_output.shape
+    graph_node_output_shape = graph_node_output.shape
     dtype = graph_node_output.dtype
 
     # Preserving Graph Structure (Dict)
     tf_layers_dict[graph_node_output.name] = {
         'optype': graph_node.op,
-        'shape': shape,
+        'shape': graph_node_output_shape,
         'dtype': dtype,
     }
 
@@ -75,6 +77,34 @@ def make_node(
     input_tensor_2 = tf_layers_dict[graph_node_input_2.name]['tf_node'] \
         if isinstance(graph_node_input_2, gs.Variable) else graph_node_input_2
 
+    # Param replacement
+    input_tensor_1 = replace_parameter(
+        value_before_replacement=input_tensor_1,
+        param_target='inputs',
+        param_name=graph_node.inputs[0].name,
+        **kwargs,
+    )
+    input_tensor_2 = replace_parameter(
+        value_before_replacement=input_tensor_2,
+        param_target='inputs',
+        param_name=graph_node.inputs[1].name,
+        **kwargs,
+    )
+
+    # Pre-process transpose
+    input_tensor_1 = pre_process_transpose(
+        value_before_transpose=input_tensor_1,
+        param_target='inputs',
+        param_name=graph_node.inputs[0].name,
+        **kwargs,
+    )
+    input_tensor_2 = pre_process_transpose(
+        value_before_transpose=input_tensor_2,
+        param_target='inputs',
+        param_name=graph_node.inputs[1].name,
+        **kwargs,
+    )
+
     # Acquisition of test data for validation
     if kwargs['acc_check']:
         if not isinstance(graph_node_input_1, np.ndarray) \
@@ -133,19 +163,13 @@ def make_node(
         **kwargs,
     )
 
-    # Param replacement
-    input_tensor_1 = replace_parameter(
-        value_before_replacement=input_tensor_1,
-        param_target='inputs',
-        param_name=graph_node.inputs[0].name,
-        **kwargs,
-    )
-    input_tensor_2 = replace_parameter(
-        value_before_replacement=input_tensor_2,
-        param_target='inputs',
-        param_name=graph_node.inputs[1].name,
-        **kwargs,
-    )
+    # Deterring shape corruption due to broadcast
+    input_tensor_1, input_tensor_2 = \
+        deterring_shape_corruption_due_to_broadcast(
+            graph_node_output_shape=graph_node_output_shape,
+            input_tensor_1=input_tensor_1,
+            input_tensor_2=input_tensor_2,
+        )
 
     # Generation of TF OP
     target_cast_dtype = [
@@ -155,20 +179,6 @@ def make_node(
         np.int64,
     ]
 
-    # Pre-process transpose
-    input_tensor_1 = pre_process_transpose(
-        value_before_transpose=input_tensor_1,
-        param_target='inputs',
-        param_name=graph_node.inputs[0].name,
-        **kwargs,
-    )
-    input_tensor_2 = pre_process_transpose(
-        value_before_transpose=input_tensor_2,
-        param_target='inputs',
-        param_name=graph_node.inputs[1].name,
-        **kwargs,
-    )
-
     # TFLite does not support TrueDiv(INT), so TrueDiv is avoided if possible
     x_is_integer = input_tensor_1.dtype in target_cast_dtype
     y_is_integer = input_tensor_2.dtype in target_cast_dtype
@@ -192,15 +202,34 @@ def make_node(
 
     # Generation of TF OP
     ### Overall model
-    divided_tensor = tf.math.divide(
-        x=input_tensor_1 \
-            if not isinstance(input_tensor_1, np.ndarray) \
-                else tf.convert_to_tensor(input_tensor_1),
-        y=input_tensor_2 \
-            if not isinstance(input_tensor_2, np.ndarray) \
-                else tf.convert_to_tensor(input_tensor_2),
-        name=graph_node.name,
+    # Merge two consecutive identical OPs into one
+    # https://github.com/PINTO0309/onnx2tf/issues/230
+    #   A constant is calculated in advance only
+    #   when one of the operations of the current OP
+    #   is a constant and one of the operations of
+    #   the next OP is also a constant.
+    # By merging two OPs into one, an accuracy error always occurs
+    # in the merged OP during the accuracy check.
+    # 1. `Mul` -> `Mul` to `Single-Mul` : `10 * 5 * 8 -> 10 * 40`
+    # 2. `Mul` -> `Div` to `Single-Mul` : `10 * 5 / 8 -> 10 * 0.625`
+    # 3. `Div` -> `Mul` to `Single-Mul` : `10 / 5 * 8 -> 10 * 1.6`
+    # 4. `Div` -> `Div` to `Single-Mul` : `10 / 5 / 8 -> 10 * 0.025`
+    # 5. `Sub` -> `Sub` to `Single-Sub` : `10 - 5 - 8 -> 10 - 13`
+    # 6. `Sub` -> `Add` to `Single-Sub` : `10 - 5 + 8 -> 10 + 3`
+    # 7. `Add` -> `Add` to `Single-Add`  : `10 + 5 + 8 -> 10 + 13`
+    # 8. `Add` -> `Sub` to `Single-Add`  : `10 + 5 - 8 -> 10 - 3`
+    divided_tensor, tf_type = merge_two_consecutive_identical_ops_into_one(
+        graph_node_input_1=graph_node_input_1,
+        graph_node_input_2=graph_node_input_2,
+        graph_node_output=graph_node_output,
+        before_op_output_shape_trans=before_op_output_shape_trans,
+        input_tensor_1=input_tensor_1,
+        input_tensor_2=input_tensor_2,
+        graph_node=graph_node,
+        tf_layers_dict=tf_layers_dict,
+        tf_func='Div'
     )
+
     ### Partial model
     if kwargs['acc_check'] and tf_partial_model_inputs is not None:
         tf_partial_model_outputs = \
@@ -261,7 +290,7 @@ def make_node(
     tf_layers_dict[graph_node_output.name]['tf_node_info'] = \
         make_tf_node_info(
             node_info={
-                'tf_op_type': tf.math.divide,
+                'tf_op_type': tf_type,
                 'tf_inputs': {
                     'x': input_tensor_1,
                     'y': input_tensor_2,
