@@ -97,6 +97,12 @@ def make_node(
     }
 
     # Generation of TF OP
+    input_tensor = input_tensor \
+        if not isinstance(input_tensor, np.ndarray) \
+            else tf.convert_to_tensor(input_tensor)
+    indices_tensor = indices_tensor \
+        if not isinstance(indices_tensor, np.ndarray) \
+            else tf.convert_to_tensor(indices_tensor)
     indices_tensor = process_neg_idx(
         data=input_tensor,
         indices=indices_tensor,
