@@ -6,6 +6,7 @@ import tensorflow as tf
 import onnx_graphsurgeon as gs
 from onnx2tf.utils.common_functions import (
     get_constant_or_variable,
+    replace_parameter,
     print_node_info,
     inverted_operation_enable_disable,
     make_tf_node_info,
@@ -18,6 +19,7 @@ from onnx2tf.utils.common_functions import (
     post_process_transpose,
     make_tf_partial_model_inputs,
     dummy_tf_inference,
+    deterring_shape_corruption_due_to_broadcast,
 )
 from typing import Any, Dict, List
 
@@ -58,13 +60,13 @@ def make_node(
         before_op_output_shape_trans,
     )
     graph_node_output: gs.Variable = graph_node.outputs[0]
-    shape = graph_node_output.shape
+    graph_node_output_shape = graph_node_output.shape
     dtype = graph_node_output.dtype
 
     # Preserving Graph Structure (Dict)
     tf_layers_dict[graph_node_output.name] = {
         'optype': graph_node.op,
-        'shape': shape,
+        'shape': graph_node_output_shape,
         'dtype': dtype,
     }
 
@@ -74,6 +76,34 @@ def make_node(
     input_tensor_2 = tf_layers_dict[graph_node_input_2.name]['tf_node'] \
         if isinstance(graph_node_input_2, gs.Variable) else graph_node_input_2
 
+    # Param replacement
+    input_tensor_1 = replace_parameter(
+        value_before_replacement=input_tensor_1,
+        param_target='inputs',
+        param_name=graph_node.inputs[0].name,
+        **kwargs,
+    )
+    input_tensor_2 = replace_parameter(
+        value_before_replacement=input_tensor_2,
+        param_target='inputs',
+        param_name=graph_node.inputs[1].name,
+        **kwargs,
+    )
+
+    # Pre-process transpose
+    input_tensor_1 = pre_process_transpose(
+        value_before_transpose=input_tensor_1,
+        param_target='inputs',
+        param_name=graph_node.inputs[0].name,
+        **kwargs,
+    )
+    input_tensor_2 = pre_process_transpose(
+        value_before_transpose=input_tensor_2,
+        param_target='inputs',
+        param_name=graph_node.inputs[1].name,
+        **kwargs,
+    )
+
     # Acquisition of test data for validation
     if kwargs['acc_check']:
         if not isinstance(graph_node_input_1, np.ndarray) \
@@ -132,19 +162,13 @@ def make_node(
         **kwargs,
     )
 
-    # Pre-process transpose
-    input_tensor_1 = pre_process_transpose(
-        value_before_transpose=input_tensor_1,
-        param_target='inputs',
-        param_name=graph_node.inputs[0].name,
-        **kwargs,
-    )
-    input_tensor_2 = pre_process_transpose(
-        value_before_transpose=input_tensor_2,
-        param_target='inputs',
-        param_name=graph_node.inputs[1].name,
-        **kwargs,
-    )
+    # Deterring shape corruption due to broadcast
+    input_tensor_1, input_tensor_2 = \
+        deterring_shape_corruption_due_to_broadcast(
+            graph_node_output_shape=graph_node_output_shape,
+            input_tensor_1=input_tensor_1,
+            input_tensor_2=input_tensor_2,
+        )
 
     # Generate input OPs for TensorFlow subgraphs
     # For inference testing on OP stand-alone
